@@ -4,5 +4,4 @@ from tests import app
 
 @app.route("/assert-xpath")
 def assert_xpath():
-    return '<data>café</data>'
-
+    return "<data>café</data>"
