@@ -1,7 +1,7 @@
 from tests import app
 from flask import request
 
+
 @app.route("/utf8_bom")
 def utf8_bom():
-    return 'Hello World!'
-
+    return "Hello World!"
