@@ -1,6 +1,6 @@
 from tests import app
 
+
 @app.route("/error-assert-header-value")
 def error_assert_header_value():
-    return 'Hello World!'
-
+    return "Hello World!"
