@@ -1,5 +1,6 @@
 from tests import app
 
+
 @app.route("/error-assert-invalid-predicate-type")
 def error_assert_invalid_predicate_type():
-   return ''
+    return ""
