@@ -1,6 +1,6 @@
 from tests import app
 
+
 @app.route("/error-assert-newline")
 def error_assert_newline():
-    return '<p>Hello</p>\n\n'
-
+    return "<p>Hello</p>\n\n"
