@@ -1,5 +1,6 @@
 from tests import app
 
+
 @app.route("/error-assert-query-invalid-xpath")
 def error_assert_query_invalid_xpath():
-    return ''
+    return ""
