@@ -1,6 +1,6 @@
 from tests import app
 
+
 @app.route("/error-assert-variable")
 def error_assert_variable():
-    return ''
-
+    return ""
