@@ -1,5 +1,6 @@
 from tests import app
 
+
 @app.route("/error-query-invalid-json")
 def error_query_invalid_json():
-    return 'Hello World!'
+    return "Hello World!"
