@@ -1,9 +1,8 @@
 from tests import app
 import time
 
-@app.route('/timeout')
+
+@app.route("/timeout")
 def timeout():
     time.sleep(2)
-    return ''
-
-
+    return ""
