@@ -1,7 +1,6 @@
 from tests import app
 
+
 @app.route("/multilines")
 def multilines():
-    return 'line1\nline2\nline3\n'
-
-
+    return "line1\nline2\nline3\n"
