@@ -1,8 +1,8 @@
 from tests import app
 from flask import request
 
+
 @app.route("/proxy")
 def proxy():
-    assert request.headers['From-Proxy'] == 'Hello'
-    return ''
-
+    assert request.headers["From-Proxy"] == "Hello"
+    return ""
