@@ -1,6 +1,7 @@
 # coding=utf-8
 from tests import app
 
+
 @app.route("/utf8")
 def utf8():
-    return '<data>café</data>'
\ No newline at end of file
+    return "<data>café</data>"
