@@ -1,6 +1,6 @@
 /*
- * hurl (https://hurl.dev)
- * Copyright (C) 2020 Orange
+ * Hurl (https://hurl.dev)
+ * Copyright (C) 2022 Orange
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -16,6 +16,8 @@
  *
  */
 
+use std::error::Error;
+
 pub use self::fs::read_to_string;
 pub use self::logger::{
     error_string, log_info, make_logger_error_message, make_logger_parser_error,
@@ -24,8 +26,9 @@ pub use self::logger::{
 pub use self::options::app;
 pub use self::options::output_color;
 pub use self::options::parse_options;
-pub use self::options::CliOptions;
+pub use self::options::{CliOptions, OutputType};
 pub use self::variables::parse as parse_variable;
+pub use self::variables::parse_value as parse_variable_value;
 
 mod fs;
 pub mod interactive;
@@ -37,3 +40,27 @@ mod variables;
 pub struct CliError {
     pub message: String,
 }
+
+impl From<Box<dyn Error>> for CliError {
+    fn from(e: Box<dyn Error>) -> Self {
+        Self {
+            message: format!("{:?}", e),
+        }
+    }
+}
+
+impl From<&str> for CliError {
+    fn from(e: &str) -> Self {
+        Self {
+            message: e.to_string(),
+        }
+    }
+}
+
+impl From<String> for CliError {
+    fn from(e: String) -> Self {
+        Self {
+            message: format!("{:?}", e),
+        }
+    }
+}
