@@ -1,6 +1,6 @@
 /*
- * hurl (https://hurl.dev)
- * Copyright (C) 2020 Orange
+ * Hurl (https://hurl.dev)
+ * Copyright (C) 2022 Orange
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -29,6 +29,7 @@ use super::entry;
 /// # Example
 ///
 /// ```
+/// use std::path::PathBuf;
 /// use hurl_core::parser;
 /// use hurl::http;
 /// use hurl::runner;
@@ -47,21 +48,7 @@ use super::entry;
 /// fn log_error(error: &runner::Error, _warning: bool) { eprintln!("* {:#?}", error); }
 ///
 /// // Create an http client
-/// let options = http::ClientOptions {
-///        cacert_file: None,
-///        follow_location: false,
-///        max_redirect: None,
-///        cookie_input_file: None,
-///        proxy: None,
-///        no_proxy: None,
-///        verbose: false,
-///        insecure: false,
-///        timeout: Default::default(),
-///        connect_timeout: Default::default(),
-///        user: None,
-///        compressed: false,
-///        context_dir: "".to_string(),
-/// };
+/// let options = http::ClientOptions::default();
 /// let mut client = http::Client::init(options);
 ///
 /// // Define runner options
@@ -70,9 +57,9 @@ use super::entry;
 ///        fail_fast: false,
 ///        variables,
 ///        to_entry: None,
-///        context_dir: "current_dir".to_string(),
+///        context_dir: PathBuf::new(),
 ///        ignore_asserts: false,
-///        pre_entry: || true,
+///        pre_entry: |_| true,
 ///        post_entry: || true,
 ///  };
 ///
@@ -121,7 +108,7 @@ pub fn run(
         .enumerate()
         .collect::<Vec<(usize, Entry)>>()
     {
-        let exit = (options.pre_entry)();
+        let exit = (options.pre_entry)(entry.clone());
         if exit {
             break;
         }
