@@ -1,3 +1,5 @@
+use std::default::Default;
+use std::path::Path;
 use std::time::Duration;
 
 use hurl::http::*;
@@ -279,6 +281,14 @@ fn test_form_params() {
                 name: "param4".to_string(),
                 value: "a%3db".to_string(),
             },
+            Param {
+                name: "values[0]".to_string(),
+                value: "0".to_string(),
+            },
+            Param {
+                name: "values[1]".to_string(),
+                value: "1".to_string(),
+            },
         ],
         multipart: vec![],
         cookies: vec![],
@@ -287,7 +297,7 @@ fn test_form_params() {
     };
     assert_eq!(
         client.curl_command_line(&request_spec),
-        "curl 'http://localhost:8000/form-params' --data 'param1=value1' --data 'param2=' --data 'param3=a%3Db' --data 'param4=a%253db'".to_string()
+        "curl 'http://localhost:8000/form-params' --data 'param1=value1' --data 'param2=' --data 'param3=a%3Db' --data 'param4=a%253db' --data 'values[0]=0' --data 'values[1]=1'".to_string()
     );
 
     let (request, response) = client.execute(&request_spec).unwrap();
@@ -341,19 +351,8 @@ fn test_follow_location() {
     let request_spec = default_get_request("http://localhost:8000/redirect".to_string());
 
     let options = ClientOptions {
-        cacert_file: None,
         follow_location: true,
-        max_redirect: Some(50),
-        cookie_input_file: None,
-        proxy: None,
-        no_proxy: None,
-        verbose: false,
-        insecure: false,
-        timeout: Duration::new(300, 0),
-        connect_timeout: Duration::new(300, 0),
-        user: None,
-        compressed: false,
-        context_dir: ".".to_string(),
+        ..Default::default()
     };
     let mut client = Client::init(options);
     assert_eq!(client.options.curl_args(), vec!["-L".to_string(),]);
@@ -395,19 +394,9 @@ fn test_follow_location() {
 #[test]
 fn test_max_redirect() {
     let options = ClientOptions {
-        cacert_file: None,
         follow_location: true,
         max_redirect: Some(10),
-        cookie_input_file: None,
-        proxy: None,
-        no_proxy: None,
-        verbose: false,
-        insecure: false,
-        timeout: Duration::new(300, 0),
-        connect_timeout: Duration::new(300, 0),
-        user: None,
-        compressed: false,
-        context_dir: ".".to_string(),
+        ..Default::default()
     };
     let mut client = Client::init(options);
 
@@ -562,19 +551,8 @@ fn test_expect() {
 #[test]
 fn test_basic_authentication() {
     let options = ClientOptions {
-        cacert_file: None,
-        follow_location: false,
-        max_redirect: Some(50),
-        cookie_input_file: None,
-        proxy: None,
-        no_proxy: None,
-        verbose: false,
-        insecure: false,
-        timeout: Duration::from_secs(300),
-        connect_timeout: Duration::from_secs(300),
         user: Some("bob:secret".to_string()),
-        compressed: false,
-        context_dir: ".".to_string(),
+        ..Default::default()
     };
     let mut client = Client::init(options);
     let request_spec = RequestSpec {
@@ -614,7 +592,7 @@ fn test_basic_authentication() {
         content_type: None,
     };
     assert_eq!(
-        request_spec.curl_args(".".to_string()),
+        request_spec.curl_args(Path::new("")),
         vec!["'http://bob:secret@localhost:8000/basic-authentication'".to_string()]
     );
     let (request, response) = client.execute(&request_spec).unwrap();
@@ -631,18 +609,7 @@ fn test_basic_authentication() {
 fn test_cacert() {
     let options = ClientOptions {
         cacert_file: Some("tests/cert.pem".to_string()),
-        follow_location: false,
-        max_redirect: None,
-        cookie_input_file: None,
-        proxy: None,
-        no_proxy: None,
-        verbose: false,
-        insecure: false,
-        timeout: Default::default(),
-        connect_timeout: Default::default(),
-        user: None,
-        compressed: false,
-        context_dir: ".".to_string(),
+        ..Default::default()
     };
     let mut client = Client::init(options);
     let request_spec = default_get_request("https://localhost:8001/hello".to_string());
@@ -676,19 +643,8 @@ fn test_error_fail_to_connect() {
     }
 
     let options = ClientOptions {
-        cacert_file: None,
-        follow_location: false,
-        max_redirect: None,
-        cookie_input_file: None,
         proxy: Some("localhost:9999".to_string()),
-        no_proxy: None,
-        verbose: true,
-        insecure: false,
-        timeout: Default::default(),
-        connect_timeout: Default::default(),
-        user: None,
-        compressed: false,
-        context_dir: ".".to_string(),
+        ..Default::default()
     };
     let mut client = Client::init(options);
     let request = default_get_request("http://localhost:8000/hello".to_string());
@@ -704,19 +660,8 @@ fn test_error_fail_to_connect() {
 #[test]
 fn test_error_could_not_resolve_proxy_name() {
     let options = ClientOptions {
-        cacert_file: None,
-        follow_location: false,
-        max_redirect: None,
-        cookie_input_file: None,
         proxy: Some("unknown".to_string()),
-        no_proxy: None,
-        verbose: false,
-        insecure: false,
-        timeout: Default::default(),
-        connect_timeout: Default::default(),
-        user: None,
-        compressed: false,
-        context_dir: ".".to_string(),
+        ..Default::default()
     };
     let mut client = Client::init(options);
     let request_spec = default_get_request("http://localhost:8000/hello".to_string());
@@ -730,21 +675,7 @@ fn test_error_could_not_resolve_proxy_name() {
 
 #[test]
 fn test_error_ssl() {
-    let options = ClientOptions {
-        cacert_file: None,
-        follow_location: false,
-        max_redirect: None,
-        cookie_input_file: None,
-        proxy: None,
-        no_proxy: None,
-        verbose: false,
-        insecure: false,
-        timeout: Default::default(),
-        connect_timeout: Default::default(),
-        user: None,
-        compressed: false,
-        context_dir: ".".to_string(),
-    };
+    let options = ClientOptions::default();
     let mut client = Client::init(options);
     let request_spec = default_get_request("https://localhost:8001/hello".to_string());
     let error = client.execute(&request_spec).err().unwrap();
@@ -762,19 +693,8 @@ fn test_error_ssl() {
 #[test]
 fn test_timeout() {
     let options = ClientOptions {
-        cacert_file: None,
-        follow_location: false,
-        max_redirect: None,
-        cookie_input_file: None,
-        proxy: None,
-        no_proxy: None,
-        verbose: false,
-        insecure: false,
         timeout: Duration::from_millis(100),
-        connect_timeout: Default::default(),
-        user: None,
-        compressed: false,
-        context_dir: ".".to_string(),
+        ..Default::default()
     };
     let mut client = Client::init(options);
     let request_spec = default_get_request("http://localhost:8000/timeout".to_string());
@@ -789,19 +709,8 @@ fn test_timeout() {
 #[test]
 fn test_accept_encoding() {
     let options = ClientOptions {
-        cacert_file: None,
-        follow_location: false,
-        max_redirect: None,
-        cookie_input_file: None,
-        proxy: None,
-        no_proxy: None,
-        verbose: true,
-        insecure: false,
-        timeout: Default::default(),
-        connect_timeout: Default::default(),
-        user: None,
         compressed: true,
-        context_dir: ".".to_string(),
+        ..Default::default()
     };
     let mut client = Client::init(options);
 
@@ -831,19 +740,8 @@ fn test_accept_encoding() {
 #[test]
 fn test_connect_timeout() {
     let options = ClientOptions {
-        cacert_file: None,
-        follow_location: false,
-        max_redirect: Some(50),
-        cookie_input_file: None,
-        proxy: None,
-        no_proxy: None,
-        verbose: false,
-        insecure: false,
-        timeout: Duration::from_secs(300),
         connect_timeout: Duration::from_secs(1),
-        user: None,
-        compressed: false,
-        context_dir: ".".to_string(),
+        ..Default::default()
     };
     let mut client = Client::init(options);
     let request_spec = default_get_request("http://10.0.0.0".to_string());
@@ -999,19 +897,8 @@ fn test_cookie_storage() {
 #[test]
 fn test_cookie_file() {
     let options = ClientOptions {
-        cacert_file: None,
-        follow_location: false,
-        max_redirect: Some(50),
         cookie_input_file: Some("tests/cookies.txt".to_string()),
-        proxy: None,
-        no_proxy: None,
-        verbose: false,
-        insecure: false,
-        timeout: Duration::new(300, 0),
-        connect_timeout: Duration::new(300, 0),
-        user: None,
-        compressed: false,
-        context_dir: ".".to_string(),
+        ..Default::default()
     };
     let mut client = Client::init(options);
     let request_spec = default_get_request(
@@ -1044,19 +931,8 @@ fn test_cookie_file() {
 fn test_proxy() {
     // mitmproxy listening on port 8888
     let options = ClientOptions {
-        cacert_file: None,
-        follow_location: false,
-        max_redirect: Some(50),
-        cookie_input_file: None,
         proxy: Some("localhost:8888".to_string()),
-        no_proxy: None,
-        verbose: false,
-        insecure: false,
-        timeout: Duration::new(300, 0),
-        connect_timeout: Duration::new(300, 0),
-        user: None,
-        compressed: false,
-        context_dir: ".".to_string(),
+        ..Default::default()
     };
     let mut client = Client::init(options);
     let request_spec = default_get_request("http://localhost:8000/proxy".to_string());
@@ -1074,19 +950,8 @@ fn test_proxy() {
 #[test]
 fn test_insecure() {
     let options = ClientOptions {
-        cacert_file: None,
-        follow_location: false,
-        max_redirect: Some(50),
-        cookie_input_file: None,
-        proxy: None,
-        no_proxy: None,
-        verbose: false,
         insecure: true,
-        timeout: Duration::new(300, 0),
-        connect_timeout: Duration::new(300, 0),
-        user: None,
-        compressed: false,
-        context_dir: ".".to_string(),
+        ..Default::default()
     };
     let mut client = Client::init(options);
     assert_eq!(client.options.curl_args(), vec!["--insecure".to_string()]);
