@@ -1,6 +1,6 @@
 /*
- * hurl (https://hurl.dev)
- * Copyright (C) 2020 Orange
+ * Hurl (https://hurl.dev)
+ * Copyright (C) 2022 Orange
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -19,6 +19,7 @@ use crate::ast::*;
 
 use super::combinators::*;
 use super::error::*;
+use super::filename;
 use super::predicate::predicate;
 use super::primitives::*;
 use super::query::query;
@@ -27,12 +28,12 @@ use super::string::*;
 use super::ParseResult;
 
 pub fn request_sections(reader: &mut Reader) -> ParseResult<'static, Vec<Section>> {
-    let sections = zero_or_more(|p1| request_section(p1), reader)?;
+    let sections = zero_or_more(request_section, reader)?;
     Ok(sections)
 }
 
 pub fn response_sections(reader: &mut Reader) -> ParseResult<'static, Vec<Section>> {
-    let sections = zero_or_more(|p1| response_section(p1), reader)?;
+    let sections = zero_or_more(response_section, reader)?;
     Ok(sections)
 }
 
@@ -48,6 +49,7 @@ fn request_section(reader: &mut Reader) -> ParseResult<'static, Section> {
     let line_terminator0 = line_terminator(reader)?;
     let value = match name.as_str() {
         "QueryStringParams" => section_value_query_params(reader)?,
+        "BasicAuth" => section_value_basic_auth(reader)?,
         "FormParams" => section_value_form_params(reader)?,
         "MultipartFormData" => section_value_multipart_form_data(reader)?,
         "Cookies" => section_value_cookies(reader)?,
@@ -114,32 +116,37 @@ fn section_name(reader: &mut Reader) -> ParseResult<'static, String> {
 }
 
 fn section_value_query_params(reader: &mut Reader) -> ParseResult<'static, SectionValue> {
-    let items = zero_or_more(|p1| key_value(p1), reader)?;
+    let items = zero_or_more(key_value, reader)?;
     Ok(SectionValue::QueryParams(items))
 }
 
+fn section_value_basic_auth(reader: &mut Reader) -> ParseResult<'static, SectionValue> {
+    let kv = key_value(reader)?;
+    Ok(SectionValue::BasicAuth(kv))
+}
+
 fn section_value_form_params(reader: &mut Reader) -> ParseResult<'static, SectionValue> {
-    let items = zero_or_more(|p1| key_value(p1), reader)?;
+    let items = zero_or_more(key_value, reader)?;
     Ok(SectionValue::FormParams(items))
 }
 
 fn section_value_multipart_form_data(reader: &mut Reader) -> ParseResult<'static, SectionValue> {
-    let items = zero_or_more(|p1| multipart_param(p1), reader)?;
+    let items = zero_or_more(multipart_param, reader)?;
     Ok(SectionValue::MultipartFormData(items))
 }
 
 fn section_value_cookies(reader: &mut Reader) -> ParseResult<'static, SectionValue> {
-    let items = zero_or_more(|p1| cookie(p1), reader)?;
+    let items = zero_or_more(cookie, reader)?;
     Ok(SectionValue::Cookies(items))
 }
 
 fn section_value_captures(reader: &mut Reader) -> ParseResult<'static, SectionValue> {
-    let items = zero_or_more(|p1| capture(p1), reader)?;
+    let items = zero_or_more(capture, reader)?;
     Ok(SectionValue::Captures(items))
 }
 
 fn section_value_asserts(reader: &mut Reader) -> ParseResult<'static, SectionValue> {
-    let asserts = zero_or_more(|p1| assert(p1), reader)?;
+    let asserts = zero_or_more(assert, reader)?;
     Ok(SectionValue::Asserts(asserts))
 }
 
@@ -174,7 +181,7 @@ fn cookie_value(reader: &mut Reader) -> CookieValue {
         c.is_ascii_alphanumeric()
             || vec![
                 '!', '#', '$', '%', '&', '\'', '(', ')', '*', '+', '-', '.', '/', ':', '<', '=',
-                '>', '?', '@', '[', ']', '^', '_', '`', '~',
+                '>', '?', '@', '[', ']', '^', '_', '`', '~', '|', '"', ';', ',',
             ]
             .contains(c)
     });
@@ -220,7 +227,7 @@ fn file_param(reader: &mut Reader) -> ParseResult<'static, FileParam> {
 fn file_value(reader: &mut Reader) -> ParseResult<'static, FileValue> {
     try_literal("file,", reader)?;
     let space0 = zero_or_more_spaces(reader)?;
-    let f = filename(reader)?;
+    let f = filename::parse(reader)?;
     let space1 = zero_or_more_spaces(reader)?;
     literal(";", reader)?;
     let save = reader.state.clone();
@@ -486,7 +493,7 @@ mod tests {
 
     #[test]
     fn test_cookie_error() {
-        let mut reader = Reader::init("Foo: \"Bar\"");
+        let mut reader = Reader::init("Foo: {Bar}");
         let error = cookie(&mut reader).err().unwrap();
         assert_eq!(error.pos, Pos { line: 1, column: 6 });
         assert!(!error.recoverable);
@@ -512,7 +519,7 @@ mod tests {
         assert_eq!(
             cookie_value(&mut reader),
             CookieValue {
-                value: String::from("")
+                value: String::from("\"Bar\"")
             }
         );
     }
