@@ -1,6 +1,6 @@
 /*
- * hurl (https://hurl.dev)
- * Copyright (C) 2020 Orange
+ * Hurl (https://hurl.dev)
+ * Copyright (C) 2022 Orange
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -245,6 +245,9 @@ impl Tokenizable for SectionValue {
                     items.iter().flat_map(|e| e.tokenize()).collect(),
                 );
             }
+            SectionValue::BasicAuth(item) => {
+                tokens.append(&mut item.tokenize());
+            }
             SectionValue::FormParams(items) => {
                 add_tokens(
                     &mut tokens,
@@ -650,6 +653,7 @@ impl Tokenizable for PredicateValue {
             PredicateValue::Hex(value) => vec![Token::String(value.to_string())],
             PredicateValue::Base64(value) => value.tokenize(),
             PredicateValue::Expression(value) => value.tokenize(),
+            PredicateValue::Regex(value) => value.tokenize(),
         }
     }
 }
@@ -732,6 +736,13 @@ impl Tokenizable for Expr {
     }
 }
 
+impl Tokenizable for Regex {
+    fn tokenize(&self) -> Vec<Token> {
+        let s = str::replace(self.inner.as_str(), "/", "\\/");
+        vec![Token::String(format!("/{}/", s))]
+    }
+}
+
 impl Tokenizable for LineTerminator {
     fn tokenize(&self) -> Vec<Token> {
         let mut tokens: Vec<Token> = vec![];
